==> polarion_rest_api_client-1.2.0-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/document_parts_list_post_request_data_item_relationships_next_part.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.document_parts_list_post_request_data_item_relationships_next_part_data import (
        DocumentPartsListPostRequestDataItemRelationshipsNextPartData,
    )


T = TypeVar(
    "T", bound="DocumentPartsListPostRequestDataItemRelationshipsNextPart"
)


@_attrs_define
class DocumentPartsListPostRequestDataItemRelationshipsNextPart:
    """
    Attributes:
        data (Union[Unset, DocumentPartsListPostRequestDataItemRelationshipsNextPartData]):
    """

    data: Union[
        Unset, "DocumentPartsListPostRequestDataItemRelationshipsNextPartData"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        data: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.document_parts_list_post_request_data_item_relationships_next_part_data import (
            DocumentPartsListPostRequestDataItemRelationshipsNextPartData,
        )

        d = src_dict.copy()
        _data = d.pop("data", UNSET)
        data: Union[
            Unset,
            DocumentPartsListPostRequestDataItemRelationshipsNextPartData,
        ]
        if isinstance(_data, Unset):
            data = UNSET
        else:
            data = DocumentPartsListPostRequestDataItemRelationshipsNextPartData.from_dict(
                _data
            )

        document_parts_list_post_request_data_item_relationships_next_part_obj = cls(
            data=data,
        )

        document_parts_list_post_request_data_item_relationships_next_part_obj.additional_properties = (
            d
        )
        return document_parts_list_post_request_data_item_relationships_next_part_obj

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> polarion_rest_api_client-1.4.1-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/document_parts_list_post_request_data_item_relationships_next_part.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.document_parts_list_post_request_data_item_relationships_next_part_data import (
        DocumentPartsListPostRequestDataItemRelationshipsNextPartData,
    )


T = TypeVar(
    "T", bound="DocumentPartsListPostRequestDataItemRelationshipsNextPart"
)


@_attrs_define
class DocumentPartsListPostRequestDataItemRelationshipsNextPart:
    """
    Attributes:
        data (Union[Unset, DocumentPartsListPostRequestDataItemRelationshipsNextPartData]):
    """

    data: Union[
        Unset, "DocumentPartsListPostRequestDataItemRelationshipsNextPartData"
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> dict[str, Any]:
        data: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.document_parts_list_post_request_data_item_relationships_next_part_data import (
            DocumentPartsListPostRequestDataItemRelationshipsNextPartData,
        )

        d = dict(src_dict)
        _data = d.pop("data", UNSET)
        data: Union[
            Unset,
            DocumentPartsListPostRequestDataItemRelationshipsNextPartData,
        ]
        if isinstance(_data, Unset):
            data = UNSET
        else:
            data = DocumentPartsListPostRequestDataItemRelationshipsNextPartData.from_dict(
                _data
            )

        document_parts_list_post_request_data_item_relationships_next_part_obj = cls(
            data=data,
        )

        document_parts_list_post_request_data_item_relationships_next_part_obj.additional_properties = (
            d
        )
        return document_parts_list_post_request_data_item_relationships_next_part_obj

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
